@@ -155,8 +155,7 @@ def visualize_train_histories(project_path: Path):
     for result_path in all_result_paths:
         tcache = TrainCache.load_from_cache_path(result_path)
         image_path = plot_dir_path / (result_path.name + ".png")
-        fig, ax = plt.subplots()
-        tcache.visualize((fig, ax))
+        fig, ax = tcache.visualize()
         fig.savefig(str(image_path))
         print("saved to {}".format(image_path))
 
@@ -196,8 +195,8 @@ def visualize_image_reconstruction(
 
             fig, (ax1, ax2) = plt.subplots(1, 2)
             fig.suptitle("left: original, right: reconstructed")
-            ax1.imshow(img.to_rgb()._data)
-            ax2.imshow(img_reconstructed.to_rgb()._data)
+            ax1.imshow(img.to_rgb().numpy())
+            ax2.imshow(img_reconstructed.to_rgb().numpy())
             filename = "result-{}-{}.png".format(postfix, i)
             if prefix is not None:
                 filename = prefix + "-" + str(filename)
@@ -227,7 +226,7 @@ def add_text_to_image(image: ImageBase, text: str, color: str):
     fig = plt.figure(tight_layout={"pad": 0})
     ax = plt.subplot(1, 1, 1)
     ax.axis("off")
-    ax.imshow(image.to_rgb()._data)
+    ax.imshow(image.to_rgb().numpy())
     bbox = dict(boxstyle="round", facecolor="white", alpha=0.4)
     ax.text(7, 1, text, fontsize=15, color=color, verticalalignment="top", bbox=bbox)
     fig.canvas.draw()
@@ -410,7 +409,7 @@ def plot_execution_result(
     project_path: Path, propagator: PropagatorBase, edict_seq: List[ElementDict], n_prop: int = 10
 ):
     timestr = "_" + time.strftime("%Y%m%d%H%M%S")
-    propagator.clear_fed_data()
+    propagator.reset()
 
     # plot actual data
     episode = EpisodeData.from_edict_list(edict_seq, check_terminate_flag=False)
